@@ -6,7 +6,7 @@ use vars qw($VERSION $AUTOLOAD);
 use Carp;
 use Net::DNS;
 
-# $Id: Question.pm,v 1.3 1997/03/28 01:22:32 mfuhr Exp $
+# $Id: Question.pm,v 1.4 1997/04/19 17:48:07 mfuhr Exp $
 $VERSION = $Net::DNS::VERSION;
 
 =head1 NAME
@@ -49,6 +49,12 @@ sub new {
 	bless \%self, $class;
 }
 
+#
+# Some people have reported that Net::DNS dies because AUTOLOAD picks up
+# calls to DESTROY.
+#
+sub DESTROY {}
+
 =head2 qname, zname
 
     print "qname = ", $question->qname, "\n";
